@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,23 +20,21 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.servicecontrol_v1.types import metric_value
 from google.cloud.servicecontrol_v1.types import quota_controller
-
 from .transports.base import QuotaControllerTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import QuotaControllerGrpcAsyncIOTransport
 from .client import QuotaControllerClient
 
 
 class QuotaControllerAsyncClient:
-    """`Google Quota Control
-    API <https://cloud.google.com/service-control/overview>`__
+    """`Google Quota Control API </service-control/overview>`__
 
     Allows clients to allocate and release quota against a `managed
     service <https://cloud.google.com/service-management/reference/rpc/google.api/servicemanagement.v1#google.api.servicemanagement.v1.ManagedService>`__.
@@ -55,24 +51,20 @@ class QuotaControllerAsyncClient:
     parse_common_billing_account_path = staticmethod(
         QuotaControllerClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(QuotaControllerClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         QuotaControllerClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         QuotaControllerClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         QuotaControllerClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(QuotaControllerClient.common_project_path)
     parse_common_project_path = staticmethod(
         QuotaControllerClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(QuotaControllerClient.common_location_path)
     parse_common_location_path = staticmethod(
         QuotaControllerClient.parse_common_location_path
@@ -80,7 +72,8 @@ class QuotaControllerAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -95,7 +88,7 @@ class QuotaControllerAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -112,7 +105,7 @@ class QuotaControllerAsyncClient:
 
     @property
     def transport(self) -> QuotaControllerTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             QuotaControllerTransport: The transport used by the client instance.
@@ -126,12 +119,12 @@ class QuotaControllerAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, QuotaControllerTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the quota controller client.
+        """Instantiates the quota controller client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -163,7 +156,6 @@ class QuotaControllerAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = QuotaControllerClient(
             credentials=credentials,
             transport=transport,
@@ -196,7 +188,6 @@ class QuotaControllerAsyncClient:
             request (:class:`google.cloud.servicecontrol_v1.types.AllocateQuotaRequest`):
                 The request object. Request message for the
                 AllocateQuota method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -210,7 +201,6 @@ class QuotaControllerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = quota_controller.AllocateQuotaRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
