@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,9 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
@@ -24,13 +23,14 @@ import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 
-from google import auth
+
+from google.api import distribution_pb2  # type: ignore
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.servicecontrol_v1.services.service_controller import (
     ServiceControllerAsyncClient,
@@ -39,19 +39,37 @@ from google.cloud.servicecontrol_v1.services.service_controller import (
     ServiceControllerClient,
 )
 from google.cloud.servicecontrol_v1.services.service_controller import transports
+from google.cloud.servicecontrol_v1.services.service_controller.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.servicecontrol_v1.types import check_error
-from google.cloud.servicecontrol_v1.types import distribution
+from google.cloud.servicecontrol_v1.types import distribution as gas_distribution
 from google.cloud.servicecontrol_v1.types import http_request
 from google.cloud.servicecontrol_v1.types import log_entry
 from google.cloud.servicecontrol_v1.types import metric_value
 from google.cloud.servicecontrol_v1.types import operation
 from google.cloud.servicecontrol_v1.types import service_controller
-from google.logging.type import log_severity_pb2 as log_severity  # type: ignore
+from google.logging.type import log_severity_pb2  # type: ignore
 from google.oauth2 import service_account
-from google.protobuf import any_pb2 as gp_any  # type: ignore
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import struct_pb2 as struct  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import any_pb2  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import struct_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+import google.auth
+
+
+# TODO(busunkim): Once google-auth >= 1.25.0 is required transitively
+# through google-api-core:
+# - Delete the auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
 
 
 def client_cert_source_callback():
@@ -103,7 +121,7 @@ def test__get_default_mtls_endpoint():
     "client_class", [ServiceControllerClient, ServiceControllerAsyncClient,]
 )
 def test_service_controller_client_from_service_account_info(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
@@ -116,11 +134,41 @@ def test_service_controller_client_from_service_account_info(client_class):
         assert client.transport._host == "servicecontrol.googleapis.com:443"
 
 
+@pytest.mark.parametrize(
+    "client_class", [ServiceControllerClient, ServiceControllerAsyncClient,]
+)
+def test_service_controller_client_service_account_always_use_jwt(client_class):
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        client = client_class(credentials=creds)
+        use_jwt.assert_not_called()
+
+
+@pytest.mark.parametrize(
+    "transport_class,transport_name",
+    [
+        (transports.ServiceControllerGrpcTransport, "grpc"),
+        (transports.ServiceControllerGrpcAsyncIOTransport, "grpc_asyncio"),
+    ],
+)
+def test_service_controller_client_service_account_always_use_jwt_true(
+    transport_class, transport_name
+):
+    with mock.patch.object(
+        service_account.Credentials, "with_always_use_jwt_access", create=True
+    ) as use_jwt:
+        creds = service_account.Credentials(None, None, None)
+        transport = transport_class(credentials=creds, always_use_jwt_access=True)
+        use_jwt.assert_called_once_with(True)
+
+
 @pytest.mark.parametrize(
     "client_class", [ServiceControllerClient, ServiceControllerAsyncClient,]
 )
 def test_service_controller_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
@@ -173,7 +221,7 @@ def test_service_controller_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(ServiceControllerClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -469,7 +517,7 @@ def test_service_controller_client_client_options_from_dict():
 
 def test_check(transport: str = "grpc", request_type=service_controller.CheckRequest):
     client = ServiceControllerClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -484,23 +532,17 @@ def test_check(transport: str = "grpc", request_type=service_controller.CheckReq
             service_config_id="service_config_id_value",
             service_rollout_id="service_rollout_id_value",
         )
-
         response = client.check(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == service_controller.CheckRequest()
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, service_controller.CheckResponse)
-
     assert response.operation_id == "operation_id_value"
-
     assert response.service_config_id == "service_config_id_value"
-
     assert response.service_rollout_id == "service_rollout_id_value"
 
 
@@ -512,7 +554,7 @@ def test_check_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = ServiceControllerClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -520,7 +562,6 @@ def test_check_empty_call():
         client.check()
         call.assert_called()
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == service_controller.CheckRequest()
 
 
@@ -529,7 +570,7 @@ async def test_check_async(
     transport: str = "grpc_asyncio", request_type=service_controller.CheckRequest
 ):
     client = ServiceControllerAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -546,22 +587,17 @@ async def test_check_async(
                 service_rollout_id="service_rollout_id_value",
             )
         )
-
         response = await client.check(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == service_controller.CheckRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, service_controller.CheckResponse)
-
     assert response.operation_id == "operation_id_value"
-
     assert response.service_config_id == "service_config_id_value"
-
     assert response.service_rollout_id == "service_rollout_id_value"
 
 
@@ -572,7 +608,7 @@ async def test_check_async_from_dict():
 
 def test_report(transport: str = "grpc", request_type=service_controller.ReportRequest):
     client = ServiceControllerClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -586,21 +622,16 @@ def test_report(transport: str = "grpc", request_type=service_controller.ReportR
             service_config_id="service_config_id_value",
             service_rollout_id="service_rollout_id_value",
         )
-
         response = client.report(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == service_controller.ReportRequest()
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, service_controller.ReportResponse)
-
     assert response.service_config_id == "service_config_id_value"
-
     assert response.service_rollout_id == "service_rollout_id_value"
 
 
@@ -612,7 +643,7 @@ def test_report_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = ServiceControllerClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -620,7 +651,6 @@ def test_report_empty_call():
         client.report()
         call.assert_called()
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == service_controller.ReportRequest()
 
 
@@ -629,7 +659,7 @@ async def test_report_async(
     transport: str = "grpc_asyncio", request_type=service_controller.ReportRequest
 ):
     client = ServiceControllerAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -645,20 +675,16 @@ async def test_report_async(
                 service_rollout_id="service_rollout_id_value",
             )
         )
-
         response = await client.report(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == service_controller.ReportRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, service_controller.ReportResponse)
-
     assert response.service_config_id == "service_config_id_value"
-
     assert response.service_rollout_id == "service_rollout_id_value"
 
 
@@ -670,16 +696,16 @@ async def test_report_async_from_dict():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.ServiceControllerGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = ServiceControllerClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.ServiceControllerGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = ServiceControllerClient(
@@ -689,7 +715,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.ServiceControllerGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = ServiceControllerClient(
@@ -700,7 +726,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.ServiceControllerGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = ServiceControllerClient(transport=transport)
     assert client.transport is transport
@@ -709,13 +735,13 @@ def test_transport_instance():
 def test_transport_get_channel():
     # A client may be instantiated with a custom transport instance.
     transport = transports.ServiceControllerGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
 
     transport = transports.ServiceControllerGrpcAsyncIOTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
@@ -730,23 +756,23 @@ def test_transport_get_channel():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = ServiceControllerClient(credentials=credentials.AnonymousCredentials(),)
+    client = ServiceControllerClient(credentials=ga_credentials.AnonymousCredentials(),)
     assert isinstance(client.transport, transports.ServiceControllerGrpcTransport,)
 
 
 def test_service_controller_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.ServiceControllerTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -758,7 +784,7 @@ def test_service_controller_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.ServiceControllerTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -772,15 +798,40 @@ def test_service_controller_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_service_controller_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.servicecontrol_v1.services.service_controller.transports.ServiceControllerTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.ServiceControllerTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/cloud-platform",
+                "https://www.googleapis.com/auth/servicecontrol",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_service_controller_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.servicecontrol_v1.services.service_controller.transports.ServiceControllerTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.ServiceControllerTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -796,19 +847,36 @@ def test_service_controller_base_transport_with_credentials_file():
 
 def test_service_controller_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.servicecontrol_v1.services.service_controller.transports.ServiceControllerTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.ServiceControllerTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_service_controller_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        ServiceControllerClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=(
+                "https://www.googleapis.com/auth/cloud-platform",
+                "https://www.googleapis.com/auth/servicecontrol",
+            ),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_service_controller_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         ServiceControllerClient()
         adc.assert_called_once_with(
             scopes=(
@@ -819,16 +887,23 @@ def test_service_controller_auth_adc():
         )
 
 
-def test_service_controller_transport_auth_adc():
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.ServiceControllerGrpcTransport,
+        transports.ServiceControllerGrpcAsyncIOTransport,
+    ],
+)
+@requires_google_auth_gte_1_25_0
+def test_service_controller_transport_auth_adc(transport_class):
     # If credentials and host are not provided, the transport class should use
     # ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
-        transports.ServiceControllerGrpcTransport(
-            host="squid.clam.whelk", quota_project_id="octopus"
-        )
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
         adc.assert_called_once_with(
-            scopes=(
+            scopes=["1", "2"],
+            default_scopes=(
                 "https://www.googleapis.com/auth/cloud-platform",
                 "https://www.googleapis.com/auth/servicecontrol",
             ),
@@ -836,6 +911,67 @@ def test_service_controller_transport_auth_adc():
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.ServiceControllerGrpcTransport,
+        transports.ServiceControllerGrpcAsyncIOTransport,
+    ],
+)
+@requires_google_auth_lt_1_25_0
+def test_service_controller_transport_auth_adc_old_google_auth(transport_class):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport_class(quota_project_id="octopus")
+        adc.assert_called_once_with(
+            scopes=(
+                "https://www.googleapis.com/auth/cloud-platform",
+                "https://www.googleapis.com/auth/servicecontrol",
+            ),
+            quota_project_id="octopus",
+        )
+
+
+@pytest.mark.parametrize(
+    "transport_class,grpc_helpers",
+    [
+        (transports.ServiceControllerGrpcTransport, grpc_helpers),
+        (transports.ServiceControllerGrpcAsyncIOTransport, grpc_helpers_async),
+    ],
+)
+def test_service_controller_transport_create_channel(transport_class, grpc_helpers):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel", autospec=True
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        adc.return_value = (creds, None)
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
+
+        create_channel.assert_called_with(
+            "servicecontrol.googleapis.com:443",
+            credentials=creds,
+            credentials_file=None,
+            quota_project_id="octopus",
+            default_scopes=(
+                "https://www.googleapis.com/auth/cloud-platform",
+                "https://www.googleapis.com/auth/servicecontrol",
+            ),
+            scopes=["1", "2"],
+            default_host="servicecontrol.googleapis.com",
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
 @pytest.mark.parametrize(
     "transport_class",
     [
@@ -844,7 +980,7 @@ def test_service_controller_transport_auth_adc():
     ],
 )
 def test_service_controller_grpc_transport_client_cert_source_for_mtls(transport_class):
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
 
     # Check ssl_channel_credentials is used if provided.
     with mock.patch.object(transport_class, "create_channel") as mock_create_channel:
@@ -858,10 +994,7 @@ def test_service_controller_grpc_transport_client_cert_source_for_mtls(transport
             "squid.clam.whelk:443",
             credentials=cred,
             credentials_file=None,
-            scopes=(
-                "https://www.googleapis.com/auth/cloud-platform",
-                "https://www.googleapis.com/auth/servicecontrol",
-            ),
+            scopes=None,
             ssl_credentials=mock_ssl_channel_creds,
             quota_project_id=None,
             options=[
@@ -886,7 +1019,7 @@ def test_service_controller_grpc_transport_client_cert_source_for_mtls(transport
 
 def test_service_controller_host_no_port():
     client = ServiceControllerClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="servicecontrol.googleapis.com"
         ),
@@ -896,7 +1029,7 @@ def test_service_controller_host_no_port():
 
 def test_service_controller_host_with_port():
     client = ServiceControllerClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="servicecontrol.googleapis.com:8000"
         ),
@@ -952,9 +1085,9 @@ def test_service_controller_transport_channel_mtls_with_client_cert_source(
             mock_grpc_channel = mock.Mock()
             grpc_create_channel.return_value = mock_grpc_channel
 
-            cred = credentials.AnonymousCredentials()
+            cred = ga_credentials.AnonymousCredentials()
             with pytest.warns(DeprecationWarning):
-                with mock.patch.object(auth, "default") as adc:
+                with mock.patch.object(google.auth, "default") as adc:
                     adc.return_value = (cred, None)
                     transport = transport_class(
                         host="squid.clam.whelk",
@@ -970,10 +1103,7 @@ def test_service_controller_transport_channel_mtls_with_client_cert_source(
                 "mtls.squid.clam.whelk:443",
                 credentials=cred,
                 credentials_file=None,
-                scopes=(
-                    "https://www.googleapis.com/auth/cloud-platform",
-                    "https://www.googleapis.com/auth/servicecontrol",
-                ),
+                scopes=None,
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
                 options=[
@@ -1020,10 +1150,7 @@ def test_service_controller_transport_channel_mtls_with_adc(transport_class):
                 "mtls.squid.clam.whelk:443",
                 credentials=mock_cred,
                 credentials_file=None,
-                scopes=(
-                    "https://www.googleapis.com/auth/cloud-platform",
-                    "https://www.googleapis.com/auth/servicecontrol",
-                ),
+                scopes=None,
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
                 options=[
@@ -1036,7 +1163,6 @@ def test_service_controller_transport_channel_mtls_with_adc(transport_class):
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1057,7 +1183,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = ServiceControllerClient.common_folder_path(folder)
     assert expected == actual
@@ -1076,7 +1201,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = ServiceControllerClient.common_organization_path(organization)
     assert expected == actual
@@ -1095,7 +1219,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = ServiceControllerClient.common_project_path(project)
     assert expected == actual
@@ -1115,7 +1238,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1142,7 +1264,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.ServiceControllerTransport, "_prep_wrapped_messages"
     ) as prep:
         client = ServiceControllerClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1151,6 +1273,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = ServiceControllerClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
